﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.Xml;
using DataDynamics.ActiveReports;
using DataDynamics.ActiveReports.Document;


namespace AddNamedItem
{
    public partial class ViewerForm : Form
    {
        public ViewerForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// This menu item shows a simple usage of AddNamedItem where a first name and a last name is accessed from a custom class or
        /// an object outside of the report class.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void simpleExampleToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Text += ": Simple Example";

            // Create an instance of ActiveReport.
            ActiveReport addNewItemRpx = new ActiveReport();
            
            // Load the AddNamedItemSimple.rpx using the LoadLayout method of ActiveReport class
            addNewItemRpx.LoadLayout(XmlReader.Create(@"..\..\AddNamedItemSimple.rpx"));

            // MyClass is a custom implementation that provides inforamtion such as First name and last name or any other 
            // custom information that needs to be passed to the report.
            // Instantiate MyClass object and assign the values to first name and last name.
            MyClass myClass = new MyClass();
            myClass.FirstName = "GrapeCity";
            myClass.LastName = "India";

            // Add the myClass instance to the report using the AddNamedItem method.
            // I use 'NameInfo' as an identifier for type 'myClass'.  This identifier is then used inside report's script 
            // to access properties and functions contained in the class MyClass.
            addNewItemRpx.AddNamedItem("NameInfo", myClass);

            // Assign the report to the viewer
            this._arViewer.Document = addNewItemRpx.Document;
            
            // run the report
            addNewItemRpx.Run();

        }

        /// <summary>
        /// This menu item shows a more general usage of data bound report with AddNamedItem,
        /// where sales tax value is provided to the report to calculate the grand total of Orders.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void databaseExampleToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Text += ": DataBase Example";

            // Create an instance of ActiveReport.
            ActiveReport addNewItemRpx = new ActiveReport();

            // Load the AddNamedItemDB.rpx using the LoadLayout method of ActiveReport class
            addNewItemRpx.LoadLayout(XmlReader.Create(@"..\..\AddNamedItemDB.rpx"));


            // MyClass is a custom implementation that provides inforamtion such as First name and last name or any other 
            // custom information that needs to be passed to the report.
            MyClass myClass = new MyClass();
            myClass.FirstName = "GrapeCity";
            myClass.LastName = "Japan";
            myClass.SalesTax = 0.085;

            // Add the myClass instance to the report using the AddNamedItem method.
            // I use 'NameInfo' as an identifier for type 'myClass'.  This identifier is then used inside report's script 
            // to access properties and functions contained in the class MyClass.
            addNewItemRpx.AddNamedItem("NameInfo", myClass);

            // NOW we provide databse connection info to the report through AddNamedItem identifier 'ConnectionInfo'
            // connection string and SQL for the data bound reoprt
            string connectionString = @"Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\Program Files (x86)\GrapeCity\ActiveReports 6\Data\NWIND.MDB;Persist Security Info=False";
            string SQL = @"SELECT * FROM Invoices WHERE Country = 'USA'";

            // MyConnection is a custom class used to provide data base connection and string information to report            
            MyConnection myDBConn = new MyConnection("OLEDB", connectionString, SQL);

            // An instance of MyConnection class is then added as a NamedItem to the report with ConnectionInfo as the identifier 
            addNewItemRpx.AddNamedItem("ConnectionInfo", myDBConn);

            // Assign the report to the viewer
            this._arViewer.Document = addNewItemRpx.Document;

            // run the report
            addNewItemRpx.Run();
            
        }

        /// <summary>
        /// This example uses an external library to provide a type for AddNamedItem
        /// The only difference between this sample and 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void externalAssemblyExampleToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Text += ": External Assembly Example";

            // Create an instance of ActiveReport.
            ActiveReport addNewItemRpx = new ActiveReport();

            // Load the AddNamedItemDB.rpx using the LoadLayout method of ActiveReport class
            addNewItemRpx.LoadLayout(XmlReader.Create(@"..\..\AddNamedItemDB.rpx"));


            // MyExternalClass is a custom implementation that exists in another assembly 'MyClassLibrary that is referenced in teh main project.
            // This class provides inforamtion such as First name and last name or any other custom information that needs to be passed to the report.
            MyClassLibrary.MyExternalClass myExternalClass = new MyClassLibrary.MyExternalClass();
            myExternalClass.FirstName = "GrapeCity";
            myExternalClass.LastName = "USA";
            myExternalClass.SalesTax = 0.075;

            // Add the myClass instance to the report using the AddNamedItem method.
            // I use 'NameInfo' as an identifier for type 'myClass'.  This identifier is then used inside report's script 
            // to access properties and functions contained in the class MyClass.
            addNewItemRpx.AddNamedItem("NameInfo", myExternalClass);

            // NOW we provide databse connection info to the report through AddNamedItem identifier 'ConnectionInfo'
            // connection string and SQL for the data bound reoprt
            string connectionString = @"Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\Program Files (x86)\GrapeCity\ActiveReports 6\Data\NWIND.MDB;Persist Security Info=False";
            string SQL = @"SELECT * FROM Invoices WHERE Country = 'USA'";

            // MyConnection is a custom class used to provide data base connection and string information to report            
            MyConnection myDBConn = new MyConnection("OLEDB", connectionString, SQL);

            // An instance of MyConnection class is then added as a NamedItem to the report with ConnectionInfo as the identifier 
            addNewItemRpx.AddNamedItem("ConnectionInfo", myDBConn);

            // Assign the report to the viewer
            this._arViewer.Document = addNewItemRpx.Document;

            // run the report
            addNewItemRpx.Run();
        }

        /// <summary>
        /// This methods uses ReportStart event outside of report script to achieve the same effect.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void usingReportStartEventToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Text += ": ReportStart Event through code Example";

            // Create an instance of ActiveReport.
            ActiveReport addNewItemRpx = new ActiveReport();

            // Load the AddNamedItemDB.rpx using the LoadLayout method of ActiveReport class
            addNewItemRpx.LoadLayout(XmlReader.Create(@"..\..\AddNamedItemDB.rpx"));

            // Attach the reportstart event
            // This is the only scenario in which the AddNewItem can be called in the ReportStart event.
            // This keeps the code related to running the reports separate and also keeps the focus on other aspect of main application related code in this method, for example.
            addNewItemRpx.ReportStart += new EventHandler(addNewItemRpx_ReportStart);

            // Assign the report to the viewer
            this._arViewer.Document = addNewItemRpx.Document;

            // run the report
            addNewItemRpx.Run();

        }

        /// <summary>
        /// Attaches to ReportStart event of Report; called from usingReportStartEventToolStripMenuItem_Click method.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void addNewItemRpx_ReportStart(object sender, EventArgs e)
        {
            ActiveReport addNewItemRpx = sender as ActiveReport;

            if (null == addNewItemRpx)
                throw new NullReferenceException("Sender is not ActiveReport: Not good!!");
            // MyExternalClass is a custom implementation that exists in another assembly 'MyClassLibrary that is referenced in teh main project.
            // This class provides inforamtion such as First name and last name or any other custom information that needs to be passed to the report.
            MyClassLibrary.MyExternalClass myExternalClass = new MyClassLibrary.MyExternalClass();
            myExternalClass.FirstName = "GrapeCity";
            myExternalClass.LastName = "Vietnam";
            myExternalClass.SalesTax = 0.065;

            // Add the myClass instance to the report using the AddNamedItem method.
            // I use 'NameInfo' as an identifier for type 'myClass'.  This identifier is then used inside report's script 
            // to access properties and functions contained in the class MyClass.
            addNewItemRpx.AddNamedItem("NameInfo", myExternalClass);

            // NOW we provide databse connection info to the report through AddNamedItem identifier 'ConnectionInfo'
            // connection string and SQL for the data bound reoprt
            string connectionString = @"Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\Program Files (x86)\GrapeCity\ActiveReports 6\Data\NWIND.MDB;Persist Security Info=False";
            string SQL = @"SELECT * FROM Invoices WHERE Country = 'USA'";

            // MyConnection is a custom class used to provide data base connection and string information to report            
            MyConnection myDBConn = new MyConnection("OLEDB", connectionString, SQL);

            // An instance of MyConnection class is then added as a NamedItem to the report with ConnectionInfo as the identifier 
            addNewItemRpx.AddNamedItem("ConnectionInfo", myDBConn);            
        }
    }
}
